Trait x_lint::file_path::FilePathLinter[][src]

pub trait FilePathLinter: Linter {
    fn run<'l>(
        &self,
        ctx: &FilePathContext<'l>,
        out: &mut LintFormatter<'l, '_>
    ) -> Result<RunStatus<'l>>; }
Represents a linter that runs once per file path.

Required methods

Executes this linter against the given file path context.

Implementors